==> owncloud-4.0.4.tgz: owncloud/apps/contacts/l10n/nb_NO.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Et problem oppsto med å (de)aktivere adresseboken.",
"There was an error adding the contact." => "Et problem oppsto med å legge til kontakten.",
"Cannot add empty property." => "Kan ikke legge til tomt felt.",
"At least one of the address fields has to be filled out." => "Minst en av adressefeltene må oppgis.",
"Error adding contact property." => "Et problem oppsto med å legge til kontaktfeltet.",
"No ID provided" => "Ingen ID angitt",
"No categories selected for deletion." => "Ingen kategorier valgt for sletting.",
"No address books found." => "Ingen adressebok funnet.",
"No contacts found." => "Ingen kontakter funnet.",
"Missing ID" => "Manglende ID",
"Cannot add addressbook with an empty name." => "Kan ikke legge til en adressebok uten navn.",
"Error adding addressbook." => "Et problem oppsto med å legge til adresseboken.",
"Error activating addressbook." => "Et problem oppsto med å aktivere adresseboken.",
"Error reading contact photo." => "Klarte ikke å lese kontaktbilde.",
"Error saving temporary file." => "Klarte ikke å lagre midlertidig fil.",
"The loading photo is not valid." => "Bildet som lastes inn er ikke gyldig.",
"id is not set." => "id er ikke satt.",
"Information about vCard is incorrect. Please reload the page." => "Informasjonen om vCard-filen er ikke riktig. Last inn siden på nytt.",
"Error deleting contact property." => "Et problem oppsto med å fjerne kontaktfeltet.",
"Missing contact id." => "Mangler kontakt-id.",
"No photo path was submitted." => "Ingen filsti ble lagt inn.",
"File doesn't exist:" => "Filen eksisterer ikke:",
"Error loading image." => "Klarte ikke å laste bilde.",
"Something went FUBAR. " => "Noe gikk fryktelig galt.",
"Error updating contact property." => "Et problem oppsto med å legge til kontaktfeltet.",
"Cannot update addressbook with an empty name." => "Kan ikke oppdatere adressebøker uten navn.",
"Error updating addressbook." => "Et problem oppsto med å oppdatere adresseboken.",
"There is no error, the file uploaded with success" => "Pust ut, ingen feil. Filen ble lastet opp problemfritt",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Filen du prøvde å laste opp var større enn grensen upload_max_filesize i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Filen du prøvde å laste opp var større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet.",
"The uploaded file was only partially uploaded" => "Filen du prøvde å laste opp ble kun delvis lastet opp",
"No file was uploaded" => "Ingen filer ble lastet opp",
"Missing a temporary folder" => "Mangler midlertidig mappe",
"Contacts" => "Kontakter",
"Addressbook not found." => "Adresseboken ble ikke funnet.",
"This is not your addressbook." => "Dette er ikke dine adressebok.",
"Contact could not be found." => "Kontakten ble ikke funnet.",
"Address" => "Adresse",
"Telephone" => "Telefon",
"Email" => "E-post",
"Organization" => "Organisasjon",
"Work" => "Arbeid",
"Home" => "Hjem",
"Mobile" => "Mobil",
"Text" => "Tekst",
"Voice" => "Svarer",
"Message" => "Melding",
"Fax" => "Faks",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internett",
"{name}'s Birthday" => "bursdagen til {name}",
"Contact" => "Kontakt",
"Add Contact" => "Ny kontakt",
"Addressbooks" => "Adressebøker",
"Configure Address Books" => "Konfigurer adressebok",
"New Address Book" => "Ny adressebok",
"Import from VCF" => "Importer fra VDF",
"CardDav Link" => "CardDAV-lenke",
"Download" => "Hent ned",
"Edit" => "Rediger",
"Delete" => "Slett",
"Download contact" => "Hend ned kontakten",
"Delete contact" => "Slett kontakt",
"Drop photo to upload" => "Dra bilder hit for å laste opp",
"Edit name details" => "Endre detaljer rundt navn",
"Nickname" => "Kallenavn",
"Enter nickname" => "Skriv inn kallenavn",
"Birthday" => "Bursdag",
"dd-mm-yyyy" => "dd-mm-åååå",
"Groups" => "Grupper",
"Separate groups with commas" => "Skill gruppene med komma",
"Edit groups" => "Endre grupper",
"Preferred" => "Foretrukket",
"Please specify a valid email address." => "Vennligst angi en gyldig e-postadresse.",
"Enter email address" => "Skriv inn e-postadresse",
"Mail to address" => "Send e-post til adresse",
"Delete email address" => "Fjern e-postadresse",
"Enter phone number" => "Skriv inn telefonnummer",
"Delete phone number" => "Fjern telefonnummer",
"View on map" => "Se på kart",
"Edit address details" => "Endre detaljer rundt adresse",
"Add notes here." => "Legg inn notater her.",
"Add field" => "Legg til felt",
"Profile picture" => "Profilbilde",
"Phone" => "Telefon",
"Note" => "Notat",
"Delete current photo" => "Fjern nåværende bilde",
"Edit current photo" => "Rediger nåværende bilde",
"Upload new photo" => "Last opp nytt bilde",
"Select photo from ownCloud" => "Velg bilde fra ownCloud",
"Edit address" => "Endre adresse",
"Type" => "Type",
"PO Box" => "Postboks",
"Extended" => "Utvidet",
"Street" => "Gate",
"City" => "By",
"Region" => "Området",
"Zipcode" => "Postnummer",
"Country" => "Land",
"Edit categories" => "Endre kategorier",
"Add" => "Ny",
"Addressbook" => "Adressebok",
"Miss" => "Frøken",
"Mr" => "Herr",
"Mrs" => "Fru",
"Dr" => "Dr",
"Given name" => "Fornavn",
"Additional names" => "Ev. mellomnavn",
"Family name" => "Etternavn",
"Hon. suffixes" => "Titler",
"Ph.D." => "Stipendiat",
"Jr." => "Jr.",
"Sn." => "Sr.",
"New Addressbook" => "Ny adressebok",
"Edit Addressbook" => "Endre adressebok",
"Displayname" => "Visningsnavn",
"Active" => "Aktiv",
"Save" => "Lagre",
"Submit" => "Lagre",
"Cancel" => "Avbryt",
"Import a contacts file" => "Importer en fil med kontakter.",
"Please choose the addressbook" => "Vennligst velg adressebok",
"create a new addressbook" => "Lag ny adressebok",
"Name of new addressbook" => "Navn på ny adressebok",
"Import" => "Importer",
"Importing contacts" => "Importerer kontakter",
"You have no contacts in your addressbook." => "Du har ingen kontakter i din adressebok",
"Add contact" => "Ny kontakt",
"Configure addressbooks" => "Konfigurer adressebøker",
"CardDAV syncing addresses" => "Synkroniseringsadresse for CardDAV",
"more info" => "mer info",
"iOS/OS X" => "iOS/OS X"
);

==> owncloud-4.5.7.tgz: owncloud/apps/contacts/l10n/nb_NO.php <==
<?php $TRANSLATIONS = array(
"Error (de)activating addressbook." => "Et problem oppsto med å (de)aktivere adresseboken.",
"id is not set." => "id er ikke satt.",
"Cannot update addressbook with an empty name." => "Kan ikke oppdatere adressebøker uten navn.",
"No ID provided" => "Ingen ID angitt",
"No categories selected for deletion." => "Ingen kategorier valgt for sletting.",
"No address books found." => "Ingen adressebok funnet.",
"No contacts found." => "Ingen kontakter funnet.",
"Cannot add empty property." => "Kan ikke legge til tomt felt.",
"At least one of the address fields has to be filled out." => "Minst en av adressefeltene må oppgis.",
"Information about vCard is incorrect. Please reload the page." => "Informasjonen om vCard-filen er ikke riktig. Last inn siden på nytt.",
"Missing ID" => "Manglende ID",
"Something went FUBAR. " => "Noe gikk fryktelig galt.",
"Error reading contact photo." => "Klarte ikke å lese kontaktbilde.",
"Error saving temporary file." => "Klarte ikke å lagre midlertidig fil.",
"The loading photo is not valid." => "Bildet som lastes inn er ikke gyldig.",
"Contact ID is missing." => "Kontakt-ID mangler.",
"No photo path was submitted." => "Ingen filsti ble lagt inn.",
"File doesn't exist:" => "Filen eksisterer ikke:",
"Error loading image." => "Klarte ikke å laste bilde.",
"Error saving contact." => "Klarte ikke å lagre kontakt.",
"Error resizing image" => "Klarte ikke å endre størrelse på bildet",
"Error cropping image" => "Klarte ikke å beskjære bildet",
"Error creating temporary image" => "Klarte ikke å lage et midlertidig bilde",
"Error finding image: " => "Kunne ikke finne bilde:",
"Error uploading contacts to storage." => "Klarte ikke å laste opp kontakter til lagringsplassen",
"There is no error, the file uploaded with success" => "Pust ut, ingen feil. Filen ble lastet opp problemfritt",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Filen du prøvde å laste opp var større enn grensen upload_max_filesize i php.ini",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Filen du prøvde å laste opp var større enn grensen satt i MAX_FILE_SIZE i HTML-skjemaet.",
"The uploaded file was only partially uploaded" => "Filen du prøvde å laste opp ble kun delvis lastet opp",
"No file was uploaded" => "Ingen filer ble lastet opp",
"Missing a temporary folder" => "Mangler midlertidig mappe",
"Couldn't save temporary image: " => "Kunne ikke lagre midlertidig bilde:",
"Couldn't load temporary image: " => "Kunne ikke laste midlertidig bilde:",
"No file was uploaded. Unknown error" => "Ingen filer ble lastet opp. Ukjent feil.",
"Contacts" => "Kontakter",
"Error" => "Feil",
"Select type" => "Velg type",
"Edit name" => "Endre navn",
"No files selected for upload." => "Ingen filer valgt for opplasting.",
"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Filen du prøver å laste opp er for stor.",
"Result: " => "Resultat:",
" imported, " => "importert,",
" failed." => "feilet.",
"Download" => "Hent ned",
"Edit" => "Rediger",
"Delete" => "Slett",
"Cancel" => "Avbryt",
"This is not your addressbook." => "Dette er ikke dine adressebok.",
"Contact could not be found." => "Kontakten ble ikke funnet.",
"Work" => "Arbeid",
"Home" => "Hjem",
"Mobile" => "Mobil",
"Text" => "Tekst",
"Voice" => "Svarer",
"Message" => "Melding",
"Fax" => "Faks",
"Video" => "Video",
"Pager" => "Pager",
"Internet" => "Internett",
"Birthday" => "Bursdag",
"{name}'s Birthday" => "{name}s bursdag",
"Contact" => "Kontakt",
"Add Contact" => "Ny kontakt",
"Import" => "Importer",
"Close" => "Lukk",
"Drop photo to upload" => "Dra bilder hit for å laste opp",
"Delete current photo" => "Fjern nåværende bilde",
"Edit current photo" => "Rediger nåværende bilde",
"Upload new photo" => "Last opp nytt bilde",
"Select photo from ownCloud" => "Velg bilde fra ownCloud",
"Edit name details" => "Endre detaljer rundt navn",
"Organization" => "Organisasjon",
"Nickname" => "Kallenavn",
"Enter nickname" => "Skriv inn kallenavn",
"dd-mm-yyyy" => "dd-mm-åååå",
"Groups" => "Grupper",
"Separate groups with commas" => "Skill gruppene med komma",
"Edit groups" => "Endre grupper",
"Preferred" => "Foretrukket",
"Please specify a valid email address." => "Vennligst angi en gyldig e-postadresse.",
"Enter email address" => "Skriv inn e-postadresse",
"Mail to address" => "Send e-post til adresse",
"Delete email address" => "Fjern e-postadresse",
"Enter phone number" => "Skriv inn telefonnummer",
"Delete phone number" => "Fjern telefonnummer",
"View on map" => "Se på kart",
"Edit address details" => "Endre detaljer rundt adresse",
"Add notes here." => "Legg inn notater her.",
"Add field" => "Legg til felt",
"Phone" => "Telefon",
"Email" => "E-post",
"Address" => "Adresse",
"Note" => "Notat",
"Download contact" => "Hend ned kontakten",
"Delete contact" => "Slett kontakt",
"The temporary image has been removed from cache." => "Det midlertidige bildet er fjernet fra cache.",
"Edit address" => "Endre adresse",
"Type" => "Type",
"PO Box" => "Postboks",
"Extended" => "Utvidet",
"City" => "By",
"Region" => "Området",
"Zipcode" => "Postnummer",
"Country" => "Land",
"Addressbook" => "Adressebok",
"Hon. prefixes" => "Ærestitler",
"Miss" => "Frøken",
"Mr" => "Herr",
"Mrs" => "Fru",
"Dr" => "Dr",
"Given name" => "Fornavn",
"Additional names" => "Ev. mellomnavn",
"Family name" => "Etternavn",
"Hon. suffixes" => "Titler",
"Ph.D." => "Stipendiat",
"Jr." => "Jr.",
"Sn." => "Sr.",
"Import a contacts file" => "Importer en fil med kontakter.",
"Please choose the addressbook" => "Vennligst velg adressebok",
"create a new addressbook" => "Lag ny adressebok",
"Name of new addressbook" => "Navn på ny adressebok",
"Importing contacts" => "Importerer kontakter",
"Add contact" => "Ny kontakt",
"CardDAV syncing addresses" => "Synkroniseringsadresse for CardDAV",
"more info" => "mer info",
"iOS/OS X" => "iOS/OS X",
"Addressbooks" => "Adressebøker",
"New Address Book" => "Ny adressebok",
"Save" => "Lagre"
);
